@@ -1,4 +1,5 @@
 import json
+import copy
 
 from alfa_sdk.common.session import Session
 
@@ -6,8 +7,11 @@ from alfa_sdk.common.session import Session
 class BaseClient:
     def __init__(self, **kwargs):
         self.session = kwargs.get("session")
+
         if self.session is None:
             self.session = Session(**kwargs)
+        else:
+            self.session = copy.copy(self.session)
 
         self.team_id = kwargs.get("team_id")
         self.user = self.session.auth.user
