@@ -34,6 +34,7 @@ class Session:
         options = self.auth.authenticate_request({})
         self.http_session = requests.Session()
         self.http_session.headers.update(options["headers"])
+        self.default_options = {}
 
     @staticmethod
     def initialize_endpoint_helper(*, context=None, **kwargs):
@@ -48,11 +49,25 @@ class Session:
 
     #
 
-    def request(self, method, service, path, *, parse=True, **kwargs):
-        url = self.endpoint.resolve(service, path)
-        kwargs = filter_none_arguments(kwargs)
-        res = self.http_session.request(method, url, **kwargs)
+    def set_default(self, options):
+        self.default_options = options
 
+    def request(self, method, *args, path=None, parse=True, **kwargs):
+        # backward compatibility
+        if len(args) >= 1:
+            kwargs["service"] = args[0]
+        if len(args) >= 2:
+            path = args[1]
+
+        service = kwargs.pop("service", self.default_options.get("service", None))
+        prefix = kwargs.pop("prefix", self.default_options.get("prefix", ""))
+        environment = kwargs.pop("environment", self.default_options.get("environment", None))
+
+        path = "{}{}".format(str(prefix), str(path))
+        url = self.endpoint.resolve(service, path, environment=environment)
+        kwargs = filter_arguments({**self.default_options, **kwargs})
+        
+        res = self.http_session.request(method, url, **kwargs)
         if parse:
             return parse_response(res)
         else:
@@ -240,7 +255,7 @@ def fetch_credentials(credentials, context):
 #
 
 
-def filter_none_arguments(kwargs):
+def filter_arguments(kwargs):
     params = kwargs.get("params")
     if isinstance(params, collections.abc.Mapping):
         params = {k: v for k, v in params.items() if v is not None}
@@ -251,4 +266,8 @@ def filter_none_arguments(kwargs):
         body = {k: v for k, v in body.items() if v is not None}
         kwargs["json"] = body
 
+    kwargs.pop("service", None)
+    kwargs.pop("prefix", None)
+    kwargs.pop("environment", None)
+
     return kwargs
