@@ -1,6 +1,8 @@
 from alfa_sdk.resources.algorithm import Algorithm
 from alfa_sdk.resources.algorithm import AlgorithmEnvironment
-from alfa_sdk.resources.release import AlgorithmRelease
+from alfa_sdk.resources.integration import Integration
+from alfa_sdk.resources.integration import IntegrationEnvironment
+from alfa_sdk.resources.release import Release
 
 from alfa_sdk.resources.meta import LocalMetaInstance
 from alfa_sdk.resources.meta import MetaUnit
