@@ -1,7 +1,7 @@
-from datetime import datetime
 from alfa_sdk.common.base import BaseResource
-from alfa_sdk.common.exceptions import ResourceDeletionError, ValidationError
+from alfa_sdk.common.exceptions import ResourceDeletionError
 from alfa_sdk.common.helpers import VersionHelper
+from alfa_sdk.common.utils import format_function_id, format_environment_id, split_environment_id
 from alfa_sdk import resources
 
 FUNCTION_TYPE = "integration"
@@ -9,7 +9,7 @@ FUNCTION_TYPE = "integration"
 
 class Integration(BaseResource):
     def __init__(self, integration_id, **kwargs):
-        self.id = integration_id
+        self.id = format_function_id(kwargs.get("team_id"), integration_id)
         super().__init__(**kwargs)
 
     def _fetch_data(self):
@@ -31,7 +31,8 @@ class Integration(BaseResource):
         return self._data.get("environments")
 
     def get_environment(self, name):
-        environment_id = "{}:{}".format(self.id, name)
+        team_id = self.team_id if self.team_id else self.user["teamId"]
+        environment_id = format_environment_id(team_id, self.id, name)
         return IntegrationEnvironment(environment_id, session=self.session)
 
     def create_environment(self, name):
@@ -40,10 +41,12 @@ class Integration(BaseResource):
 
 class IntegrationEnvironment(BaseResource):
     def __init__(self, environment_id, **kwargs):
-        team_id, integration, environment = environment_id.split(":")
-        self.environment = environment
-        self.integration_id = "{}:{}".format(team_id, integration)
+        team_id, integration, environment = split_environment_id(environment_id)
+
         self.id = environment_id
+        self.integration_id = format_function_id(team_id, integration)
+        self.environment = environment
+        
         super().__init__(**kwargs)
 
     def _fetch_data(self):
